﻿using Ink.Runtime;
using UnityEngine;

namespace HutongGames.PlayMaker.Actions
{

	public class InkGetNextChoice : FsmStateAction 
	{
		[RequiredField]
		[UIHint(UIHint.Variable)]
		[CheckForComponent(typeof(PlaymakerInkProxy))]
		[Tooltip("We need a PlaymakerInkProxy script.")]
		public PlaymakerInkProxy proxy;

		[RequiredField]
		[UIHint(UIHint.Variable)]
		[Tooltip("String to return choice into (sends 1 line at a time).")]
		public FsmString returnString;

		[UIHint(UIHint.Variable)]
		[Tooltip("The current choice index (int).")]
		public FsmInt returnInt;

		[Tooltip("Event to send with each choice.")]
		public FsmEvent loopEvent;

		[Tooltip("Event to send when finished.")]
		public FsmEvent finishedEvent;

		private int index = 0;

		public override void Reset()
		{
			proxy = null;
			returnString = null;
			loopEvent = null;
			finishedEvent = null;
		}

		public override void OnEnter()
		{
			DoContinue ();
			Finish ();
		}

		void DoContinue()
		{
			if (index >= proxy.currentChoiceCount())
			{
				index = 0;
				Fsm.Event (finishedEvent);
				return;
			}

			GetCurrentChoice ();

			if (index >= proxy.currentChoiceCount())
			{
				index = 0;
				Fsm.Event (finishedEvent);
				return;
			}

			index++;

			if (loopEvent != null) {
				Fsm.Event (loopEvent);
			}
		}

		void GetCurrentChoice()
		{
			returnString.Value = proxy.getChoiceString (index);
			returnInt.Value = index;
		}



	}
}
